@@ -3,7 +3,7 @@ package Code::Includable::Tree::NodeMethods;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-04-14'; # DATE
 our $DIST = 'Role-TinyCommons-Tree'; # DIST
-our $VERSION = '0.123'; # VERSION
+our $VERSION = '0.124'; # VERSION
 
 use strict;
 our $IGNORE_NO_CHILDREN_METHOD = 1;
@@ -37,6 +37,7 @@ sub _children_as_list {
     @children;
 }
 
+# direct children first
 sub _descendants {
     my ($self, $res) = @_;
     my @children = _children_as_list($self);
@@ -51,6 +52,22 @@ sub descendants {
     @$res;
 }
 
+sub _descendants_depth_first {
+    my ($self, $res) = @_;
+    my @children = _children_as_list($self);
+    for (@children) {
+        push @$res, $_;
+        _descendants_depth_first($_, $res);
+    }
+}
+
+sub descendants_depth_first {
+    my $self = shift;
+    my $res = [];
+    _descendants_depth_first($self, $res);
+    @$res;
+}
+
 sub ancestors {
     my $self = shift;
     my @res;
@@ -272,7 +289,7 @@ Code::Includable::Tree::NodeMethods - Tree node routines
 
 =head1 VERSION
 
-This document describes version 0.123 of Code::Includable::Tree::NodeMethods (from Perl distribution Role-TinyCommons-Tree), released on 2020-04-14.
+This document describes version 0.124 of Code::Includable::Tree::NodeMethods (from Perl distribution Role-TinyCommons-Tree), released on 2020-04-14.
 
 =head1 DESCRIPTION
 
@@ -347,6 +364,30 @@ root node).
 Return a list of descendents, from the direct children, to their children's
 children, and so on until all the leaf nodes.
 
+For example, for this tree:
+
+ A
+ |-- B
+ |   |-- D
+ |   |-- E
+ |   `-- F
+ `-- C
+     |-- G
+     |   `-- I
+     `-- H
+
+the nodes returned for C<< descendants(A) >> would be:
+
+ B C D E F G H I
+
+=head2 descendants_depth_first
+
+Like L</descendants>, except will return in depth-first order. For example,
+using the same object in the L</descendants> example, C<<
+descendants_depth_first(A) >> will return:
+
+ B D E F C G I H
+
 =head2 first_node
 
 Usage:
