@@ -1,5 +1,10 @@
 package Test::Role::TinyCommons::Tree;
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-04-14'; # DATE
+our $DIST = 'Role-TinyCommons-Tree'; # DIST
+our $VERSION = '0.124'; # VERSION
+
 use strict;
 use warnings;
 use Test::Exception;
@@ -152,6 +157,13 @@ sub test_role_tinycommons_tree {
                   [$n1, $n2, $n3, $n4, $n5, $n6, $n7, $n8, $n9],
                   "descendants (sub call)");
 
+        is_deeply([$n0->descendants_depth_first],
+                  [$n1, $n3, $n4, $n5, $n6, $n7, $n2, $n8, $n9],
+                  "descendants_depth_first");
+        is_deeply([Code::Includable::Tree::NodeMethods::descendants_depth_first($n0)],
+                  [$n1, $n3, $n4, $n5, $n6, $n7, $n2, $n8, $n9],
+                  "descendants_depth_first (sub call)");
+
         # XXX test walk
 
         is_deeply($n0->first_node(sub { $_[0]->id == 5 }),
@@ -325,7 +337,7 @@ Test::Role::TinyCommons::Tree - Test suite for Role::TinyCommons::Tree
 
 =head1 VERSION
 
-This document describes version 0.123 of Test::Role::TinyCommons::Tree (from Perl distribution Role-TinyCommons-Tree), released on 2020-04-14.
+This document describes version 0.124 of Test::Role::TinyCommons::Tree (from Perl distribution Role-TinyCommons-Tree), released on 2020-04-14.
 
 =head1 DESCRIPTION
 
